From 31e119c1adc34fabbf87d4516c8e37e1cd41e90b Mon Sep 17 00:00:00 2001
From: amit <amitlangote09@gmail.com>
Date: Tue, 6 Feb 2018 10:40:45 +0900
Subject: [PATCH v1] Fix trigger behavior with update tuple routing

Trigger stats shown by EXPLAIN ANALYZE may contain duplicate
entries, because leaf partitions' ResultRelInfo is redundantly
present in multiple EState lists.

Reported by: Etsuro Fujita
---
 src/backend/executor/execPartition.c | 10 +++++++---
 1 file changed, 7 insertions(+), 3 deletions(-)

diff --git a/src/backend/executor/execPartition.c b/src/backend/executor/execPartition.c
index 106a96d910..619a8d7a99 100644
--- a/src/backend/executor/execPartition.c
+++ b/src/backend/executor/execPartition.c
@@ -178,6 +178,13 @@ ExecSetupPartitionTupleRouting(ModifyTableState *mtstate,
 							  resultRTindex,
 							  rel,
 							  estate->es_instrument);
+
+			/*
+			 * Since we're newly creating this ResultRelInfo, add it to
+			 * someplace where explain.c could find them.
+			 */
+			estate->es_leaf_result_relations =
+				lappend(estate->es_leaf_result_relations, leaf_part_rri);
 		}
 
 		part_tupdesc = RelationGetDescr(partrel);
@@ -210,9 +217,6 @@ ExecSetupPartitionTupleRouting(ModifyTableState *mtstate,
 							mtstate != NULL &&
 							mtstate->mt_onconflict != ONCONFLICT_NONE);
 
-		estate->es_leaf_result_relations =
-			lappend(estate->es_leaf_result_relations, leaf_part_rri);
-
 		proute->partitions[i] = leaf_part_rri;
 		i++;
 	}
-- 
2.11.0

